<a href="https://zoho.com/catalyst/">
    <img width="150" height="150" src="https://static.zohocdn.com/catalyst-cdn/img/Catalyst-Logo-857518f26c.svg">
</a>

<h1>ZCatalyst SDK</h1>

<p>
  The official python sdk of Catalyst by Zoho
</p>
<br>

![PyPI](https://img.shields.io/pypi/v/zcatalyst_sdk)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/zcatalyst_sdk)
![PyPI - Wheel](https://img.shields.io/pypi/wheel/zcatalyst_sdk)
![PyPI - License](https://img.shields.io/pypi/l/zcatalyst_sdk)

ZCatalyst Python SDK bundles all the features of Zoho Catalyst and provides access to various Catalyst services and their respective components, which helps you build robust Catalyst applications and microservices.

## Prerequisites

To start working with this SDK you need a catalyst account [Sign Up](https://catalyst.zoho.com/)

Then you need to install suitable version of [Python](https://www.python.org/) and [pip](https://pip.pypa.io/en/stable/installation/)

## Installing

The ZCatalyst Python SDK is a pip package and can be found as zcatalyst on PyPI:

```bash
python -m pip install zcatalyst-sdk
```

## Using zcatalyst

After installing zcatalyst, you can initialize it in your catalyst functions as:

```python
import zcatalyst_sdk

catalyst_app = zcatalyst_sdk.initialize()
```

## Documentation

For documentation and further clarifications kindly contanct [support@zohocatalyst.com](mailto:support@zohocatalyst.com)
